@@ -1,7 +1,7 @@
 # This file is part of the bumpver project
 # https://gitlab.com/mbarkhau/bumpver
 #
-# Copyright (c) 2018-2024 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
+# Copyright (c) 2018-2025 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
 # SPDX-License-Identifier: MIT
 """Parse bumpver.toml, setup.cfg or pyproject.toml files."""
 
@@ -25,9 +25,8 @@ from .patterns import Pattern
 
 logger = logging.getLogger("bumpver.config")
 
-RawPatterns         = typ.List[str]
-RawPatternsByFile   = typ.Dict[str, RawPatterns]
-FileRawPatternsItem = typ.Tuple[str, RawPatterns]
+RawPatternsByFile   = typ.Dict[str, typ.Union[str, typ.List[str]]]
+FileRawPatternsItem = typ.Tuple[str, typ.List[str]]
 
 PatternsByFile   = typ.Dict[str, typ.List[Pattern]]
 FilePatternsItem = typ.Tuple[str, typ.List[Pattern]]
@@ -276,6 +275,9 @@ def _iter_glob_expanded_file_patterns(
     raw_patterns_by_file: RawPatternsByFile,
 ) -> typ.Iterator[FileRawPatternsItem]:
     for filepath_glob, raw_patterns in raw_patterns_by_file.items():
+        if isinstance(raw_patterns, str):
+            raw_patterns = [raw_patterns]
+
         filepaths = list(pl.Path().glob(filepath_glob))
 
         if filepaths:
