@@ -1,7 +1,7 @@
 # This file is part of the bumpver project
 # https://github.com/mbarkhau/bumpver
 #
-# Copyright (c) 2018-2024 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
+# Copyright (c) 2018-2025 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
 # SPDX-License-Identifier: MIT
 """Rewrite files, updating occurences of version strings."""
 
@@ -26,7 +26,7 @@ def rewrite_lines(
     new_vinfo: version.V2VersionInfo,
     old_lines: typ.List[str],
 ) -> typ.List[str]:
-    """Replace occurances of patterns in old_lines with new_vinfo."""
+    """Replace occurences of patterns in old_lines with new_vinfo."""
     found_patterns: typ.Set[Pattern] = set()
 
     new_lines = old_lines[:]
