@@ -10,15 +10,18 @@ import re
 import time
 import shlex
 import shutil
+import logging
 import datetime as dt
 import subprocess as sp
+from test import util
 
 import pytest
-import pathlib2 as pl
 from click.testing import CliRunner
 
 from bumpver import cli
+from bumpver import utils
 from bumpver import config
+from bumpver import pathlib as pl
 from bumpver import v2patterns
 
 # pylint:disable=redefined-outer-name ; pytest fixtures
@@ -156,6 +159,33 @@ def test_incr_pin_date(runner):
     assert "Version: v2017.22000-alpha\n" in result.output
 
 
+@pytest.mark.parametrize(
+    "version_pattern, old_version, new_version",
+    [
+        ("vYYYY.INC0[-PATCH]", "v2017.0", "v2017.0-1"),
+        ("vYYYY.INC0[-PATCH]", "v2017.0-1", "v2017.0-2"),
+        ("vYYYY.INC1[-PATCH]", "v2017.1", "v2017.1-1"),
+        ("vYYYY.INC1[-PATCH]", "v2017.1-1", "v2017.1-2"),
+    ],
+)
+def test_incr_pin_increments(runner, version_pattern, old_version, new_version):
+    result = runner.invoke(
+        cli.cli,
+        [
+            'test',
+            "-vv",
+            "--pin-increments",
+            "--patch",
+            "--date",
+            "2017-12-01",
+            old_version,
+            version_pattern,
+        ],
+    )
+    assert result.exit_code == 0
+    assert f"Version: {new_version}\n" in result.output
+
+
 def test_incr_semver(runner):
     semver_patterns = [
         "{semver}",
@@ -199,7 +229,7 @@ def test_incr_semver_invalid(runner, caplog):
 def test_incr_to_beta(runner):
     pattern     = "vYYYY.BUILD[-TAG]"
     old_version = "v2017.1999-alpha"
-    new_version = dt.datetime.utcnow().strftime("v%Y.22000-beta")
+    new_version = utils.now().strftime("v%Y.22000-beta")
 
     result = runner.invoke(cli.cli, ['test', "-vv", old_version, pattern, "--tag", "beta"])
     assert result.exit_code == 0
@@ -209,7 +239,7 @@ def test_incr_to_beta(runner):
 def test_incr_to_final(runner, caplog):
     pattern     = "vYYYY.BUILD[-TAG]"
     old_version = "v2017.1999-alpha"
-    new_version = dt.datetime.utcnow().strftime("v%Y.22000")
+    new_version = utils.now().strftime("v%Y.22000")
 
     result = runner.invoke(cli.cli, ['test', "-vv", old_version, pattern, "--tag", "final"])
     _debug_records(caplog)
@@ -224,9 +254,16 @@ def test_incr_tag(runner):
     old_version = "0.1.0"
     new_version = "0.1.1b0"
 
-    result = runner.invoke(
-        cli.cli, ['test', "-vv", old_version, SEMVER, "--patch", "--tag", "beta"]
-    )
+    result = runner.invoke(cli.cli, ['test', "-vv", old_version, SEMVER, "--patch", "--tag", "beta"])
+    assert result.exit_code == 0
+    assert f"Version: {new_version}\n" in result.output
+
+
+def test_dev_tag(runner):
+    old_version = "0.1.0"
+    new_version = "0.1.1dev0"
+
+    result = runner.invoke(cli.cli, ['test', "-vv", old_version, SEMVER, "--patch", "--tag", "dev"])
     assert result.exit_code == 0
     assert f"Version: {new_version}\n" in result.output
 
@@ -311,7 +348,8 @@ def test_novcs_nocfg_init(runner, caplog):
         cfg_content = fobj.read()
 
     base_str = config.DEFAULT_BUMPVER_TOML_BASE_TMPL.format(
-        initial_version=config._initial_version()
+        initial_version=config._initial_version(),
+        default_tag_scope=config.DEFAULT_TAG_SCOPE.value,
     )
     assert base_str                          in cfg_content
     assert config.DEFAULT_TOML_README_MD_STR in cfg_content
@@ -342,7 +380,8 @@ def test_novcs_setupcfg_init(runner):
         cfg_content = fobj.read()
 
     base_str = config.DEFAULT_CONFIGPARSER_BASE_TMPL.format(
-        initial_version=config._initial_version()
+        initial_version=config._initial_version(),
+        default_tag_scope=config.DEFAULT_TAG_SCOPE.value,
     )
     assert base_str                                  in cfg_content
     assert config.DEFAULT_CONFIGPARSER_README_MD_STR in cfg_content
@@ -381,7 +420,8 @@ def test_novcs_pyproject_init(runner, caplog):
         cfg_content = fobj.read()
 
     base_str = config.DEFAULT_PYPROJECT_TOML_BASE_TMPL.format(
-        initial_version=config._initial_version()
+        initial_version=config._initial_version(),
+        default_tag_scope=config.DEFAULT_TAG_SCOPE.value,
     )
     assert base_str                          in cfg_content
     assert config.DEFAULT_TOML_README_MD_STR in cfg_content
@@ -404,7 +444,7 @@ def _vcs_init(vcs, files=("README.md",)):
     shell(f"{vcs}", "commit", "-m", "initial commit")
 
 
-_today = dt.datetime.utcnow().date()
+_today = utils.now().date()
 
 
 DEFAULT_VERSION_PATTERNS = [
@@ -519,7 +559,7 @@ def test_novcs_bump(runner, version_pattern, cur_version, cur_pep440):
         current_version='"' + cur_version + '"',
     )
 
-    with pl.Path("README.md").open(mode="r") as fobj:
+    with pl.Path("README.md").open(mode="r", encoding="utf-8") as fobj:
         content = fobj.read()
 
     result = runner.invoke(cli.cli, ['update', "-vv"])
@@ -527,7 +567,7 @@ def test_novcs_bump(runner, version_pattern, cur_version, cur_pep440):
 
     calver = cur_version.split(".")[0]
 
-    with pl.Path("README.md").open() as fobj:
+    with pl.Path("README.md").open(encoding="utf-8") as fobj:
         content = fobj.read()
         assert calver + ".1002-alpha !\n" in content
         assert calver[1:] + ".1002a0 !]\n" in content
@@ -535,7 +575,7 @@ def test_novcs_bump(runner, version_pattern, cur_version, cur_pep440):
     result = runner.invoke(cli.cli, ['update', "-vv", "--tag", "beta"])
     assert result.exit_code == 0
 
-    with pl.Path("README.md").open() as fobj:
+    with pl.Path("README.md").open(encoding="utf-8") as fobj:
         content = fobj.read()
         assert calver + ".1003-beta !\n" in content
         assert calver[1:] + ".1003b0 !]\n" in content
@@ -564,7 +604,7 @@ def test_git_bump(runner, caplog, version_pattern, cur_version, cur_pep440):
 
     calver = cur_version.split(".")[0]
 
-    with pl.Path("README.md").open() as fobj:
+    with pl.Path("README.md").open(encoding="utf-8") as fobj:
         content = fobj.read()
         assert calver + ".1002-alpha !\n" in content
 
@@ -591,20 +631,20 @@ def test_hg_bump(runner, version_pattern, cur_version, cur_pep440):
 
     calver = cur_version.split(".")[0]
 
-    with pl.Path("README.md").open() as fobj:
+    with pl.Path("README.md").open(encoding="utf-8") as fobj:
         content = fobj.read()
         assert calver + ".1002-alpha !\n" in content
 
 
 def test_empty_git_bump(runner, caplog):
     shell("git", "init")
-    with pl.Path("setup.cfg").open(mode="w") as fobj:
+    with pl.Path("setup.cfg").open(mode="w", encoding="utf-8") as fobj:
         fobj.write("")
 
     result = runner.invoke(cli.cli, ['init', "-vv"])
     assert result.exit_code == 0
 
-    with pl.Path("setup.cfg").open(mode="r") as fobj:
+    with pl.Path("setup.cfg").open(mode="r", encoding="utf-8") as fobj:
         default_cfg_data = fobj.read()
 
     assert "[bumpver]\n" in default_cfg_data
@@ -620,13 +660,13 @@ def test_empty_git_bump(runner, caplog):
 
 def test_empty_hg_bump(runner, caplog):
     shell("hg", "init")
-    with pl.Path("setup.cfg").open(mode="w") as fobj:
+    with pl.Path("setup.cfg").open(mode="w", encoding="utf-8") as fobj:
         fobj.write("")
 
     result = runner.invoke(cli.cli, ['init', "-vv"])
     assert result.exit_code == 0
 
-    with pl.Path("setup.cfg").open(mode="r") as fobj:
+    with pl.Path("setup.cfg").open(mode="r", encoding="utf-8") as fobj:
         default_cfg_text = fobj.read()
 
     assert "[bumpver]\n" in default_cfg_text
@@ -691,9 +731,7 @@ def test_incorrect_vcs_option_tag_push(runner, caplog):
     result = runner.invoke(cli.cli, ['update', "-vv", "--tag-commit"])
     assert result.exit_code == 1
     assert len(caplog.records) == 1
-    expected = (
-        "Invalid argument: --tag-commit requires either --commit or commit=True in your config"
-    )
+    expected = "Invalid argument: --tag-commit requires either --commit or commit=True in your config"
     assert expected in caplog.records[0].message
 
     result = runner.invoke(cli.cli, ['update', "-vv", "--push"])
@@ -849,7 +887,7 @@ DEFAULT_SEMVER_PATTERNS = [
 def test_update_semver_warning(runner, caplog, version_pattern):
     _add_project_files("README.md")
 
-    with pl.Path("setup.cfg").open(mode="w") as fobj:
+    with pl.Path("setup.cfg").open(mode="w", encoding="utf-8") as fobj:
         fobj.write(SETUP_CFG_SEMVER_FIXTURE)
 
     _update_config_val("setup.cfg", version_pattern=version_pattern)
@@ -870,7 +908,7 @@ def test_update_semver_warning(runner, caplog, version_pattern):
 def test_update_semver_diff(runner, caplog, version_pattern):
     _add_project_files("README.md")
 
-    with pl.Path("setup.cfg").open(mode="w") as fobj:
+    with pl.Path("setup.cfg").open(mode="w", encoding="utf-8") as fobj:
         fobj.write(SETUP_CFG_SEMVER_FIXTURE)
 
     _update_config_val("setup.cfg", version_pattern=version_pattern)
@@ -894,7 +932,7 @@ def test_update_semver_diff(runner, caplog, version_pattern):
 def test_update_set_version(runner, caplog):
     _add_project_files("README.md", "setup.cfg")
 
-    with pl.Path("setup.cfg").open(mode="w") as fobj:
+    with pl.Path("setup.cfg").open(mode="w", encoding="utf-8") as fobj:
         fobj.write(SETUP_CFG_SEMVER_FIXTURE)
 
     _update_config_val(
@@ -903,9 +941,7 @@ def test_update_set_version(runner, caplog):
         current_version='"v2020.1001-alpha"',
     )
 
-    result = runner.invoke(
-        cli.cli, ['update', "-vv", "-n", "--dry", "--set-version", "v2121.1234-beta"]
-    )
+    result = runner.invoke(cli.cli, ['update', "-vv", "-n", "--dry", "--set-version", "v2121.1234-beta"])
     assert result.exit_code == 0
     assert len(caplog.records) == 0
 
@@ -913,9 +949,7 @@ def test_update_set_version(runner, caplog):
     assert '-current_version = "v2020.1001-alpha"' in out_lines
     assert '+current_version = "v2121.1234-beta"' in out_lines
 
-    result = runner.invoke(
-        cli.cli, ['update', "-vv", "-n", "--dry", "--set-version", "2020.1234-invalid"]
-    )
+    result = runner.invoke(cli.cli, ['update', "-vv", "-n", "--dry", "--set-version", "2020.1234-invalid"])
     assert result.exit_code == 1
     assert len(caplog.records) > 0
 
@@ -1108,6 +1142,172 @@ def test_cli_commit_message(runner, caplog):
     assert expected in commits[1]
 
 
+def test_hg_tag_message(runner, caplog):
+    _add_project_files("README.md", "setup.cfg")
+    result = runner.invoke(cli.cli, ['init', "-vv"])
+    assert result.exit_code == 0
+
+    tag_message = """
+    "bump: {old_version} ({old_version_pep440}) -> {new_version} ({new_version_pep440})"
+    """
+
+    _update_config_val(
+        "setup.cfg",
+        current_version='"v2019.1001-alpha"',
+        version_pattern="vYYYY.BUILD[-TAG]",
+        tag_message=tag_message.strip(),
+    )
+
+    _vcs_init("hg", ["README.md", "setup.cfg"])
+    assert len(caplog.records) > 0
+
+    cmd = [
+        'update',
+        "-vv",
+        "--pin-date",
+        "--tag",
+        "beta",
+    ]
+
+    result = runner.invoke(cli.cli, cmd)
+    assert result.exit_code == 0
+
+    tags = shell("hg", "tags").decode("utf-8")
+
+    expected_tag = "v2019.1002-beta"
+    assert expected_tag in tags
+
+    latest_changeset = shell("hg", "log", "-l", "1").decode("utf-8")
+
+    expected_message = "bump: v2019.1001-alpha (2019.1001a0) -> v2019.1002-beta (2019.1002b0)"
+    assert expected_message in latest_changeset.split("summery:", 1)[-1]
+
+
+def test_git_tag_message_annotated(runner, caplog):
+    _add_project_files("README.md", "setup.cfg")
+    result = runner.invoke(cli.cli, ['init', "-vv"])
+    assert result.exit_code == 0
+
+    tag_message = """
+    "bump: {old_version} ({old_version_pep440}) -> {new_version} ({new_version_pep440})"
+    """
+
+    _update_config_val(
+        "setup.cfg",
+        current_version='"v2019.1001-alpha"',
+        version_pattern="vYYYY.BUILD[-TAG]",
+        tag_message=tag_message.strip(),
+    )
+
+    _vcs_init("git", ["README.md", "setup.cfg"])
+    assert len(caplog.records) > 0
+
+    cmd = [
+        'update',
+        "-vv",
+        "--pin-date",
+        "--tag",
+        "beta",
+    ]
+
+    result = runner.invoke(cli.cli, cmd)
+    assert result.exit_code == 0
+
+    tags = shell("git", "tag", "--list").decode("utf-8")
+
+    expected_tag = "v2019.1002-beta"
+    assert expected_tag in tags
+
+    objecttype = shell("git", "tag", "--list", expected_tag, "--format=%(objecttype)").decode("utf-8").strip()
+
+    expected_type = "tag"
+    assert objecttype == expected_type
+
+    message = (
+        shell("git", "tag", "--list", expected_tag, "--format=%(contents:subject)").decode("utf-8").strip()
+    )
+
+    expected_message = "bump: v2019.1001-alpha (2019.1001a0) -> v2019.1002-beta (2019.1002b0)"
+    assert expected_message == message
+
+
+def test_git_tag_message_lightweight(runner, caplog):
+    _add_project_files("README.md", "setup.cfg")
+    result = runner.invoke(cli.cli, ['init', "-vv"])
+    assert result.exit_code == 0
+
+    _update_config_val(
+        "setup.cfg",
+        current_version='"v2019.1001-alpha"',
+        version_pattern="vYYYY.BUILD[-TAG]",
+        tag_message='""',
+    )
+
+    _vcs_init("git", ["README.md", "setup.cfg"])
+    assert len(caplog.records) > 0
+
+    cmd = [
+        'update',
+        "-vv",
+        "--pin-date",
+        "--tag",
+        "beta",
+    ]
+
+    result = runner.invoke(cli.cli, cmd)
+    assert result.exit_code == 0
+
+    tags = shell("git", "tag", "--list").decode("utf-8")
+
+    expected_tag = "v2019.1002-beta"
+    assert expected_tag in tags
+
+    objecttype = shell("git", "tag", "--list", expected_tag, "--format=%(objecttype)").decode("utf-8").strip()
+
+    expected_type = "commit"
+    assert objecttype == expected_type
+
+
+def test_cli_tag_message(runner, caplog):
+    _add_project_files("README.md", "setup.cfg")
+    result = runner.invoke(cli.cli, ['init', "-vv"])
+    assert result.exit_code == 0
+
+    _update_config_val(
+        "setup.cfg",
+        current_version='"v2019.1001-alpha"',
+        version_pattern="vYYYY.BUILD[-TAG]",
+    )
+
+    _vcs_init("git", ["README.md", "setup.cfg"])
+    assert len(caplog.records) > 0
+
+    cmd = [
+        'update',
+        "-vv",
+        "--pin-date",
+        "--tag",
+        "beta",
+        "--tag-message",
+        "my custom message (OLD -> NEW)",
+    ]
+
+    result = runner.invoke(cli.cli, cmd)
+    assert result.exit_code == 0
+
+    tags = shell("git", "tag", "--list").decode("utf-8")
+
+    expected_tag = "v2019.1002-beta"
+    assert expected_tag in tags
+
+    message = (
+        shell("git", "tag", "--list", expected_tag, "--format=%(contents:subject)").decode("utf-8").strip()
+    )
+
+    expected_message = "my custom message (v2019.1001-alpha -> v2019.1002-beta)"
+    assert expected_message == message
+
+
 def test_grep(runner):
     _add_project_files("README.md")
 
@@ -1236,15 +1436,31 @@ def test_rollover(version_pattern, old_version, expected, kwargs):
         assert new_version == expected
 
 
-def test_get_latest_vcs_version_tag(runner):
+VCS_VERSION_TAG_CASES = [
+    ("git", None, "0.2.1"),
+    ("git", config.TagScope.GLOBAL, "0.2.1"),
+    ("git", config.TagScope.BRANCH, "0.1.10"),
+    ("git", config.TagScope.DEFAULT, "0.2.1"),
+    ("hg", None, "0.2.1"),
+    ("hg", config.TagScope.GLOBAL, "0.2.1"),
+    ("hg", config.TagScope.BRANCH, "0.1.10"),
+    ("hg", config.TagScope.DEFAULT, "0.2.1"),
+]
+
+
+@pytest.mark.parametrize("vcs_name, tag_scope, expected_version", VCS_VERSION_TAG_CASES)
+def test_get_latest_vcs_version_tag(runner, vcs_name, tag_scope, expected_version):
     result = runner.invoke(cli.cli, ['init', "-vv"])
     assert result.exit_code == 0
 
     _update_config_val("bumpver.toml", push="false")
     _update_config_val("bumpver.toml", current_version='"0.1.8"')
-    _update_config_val("bumpver.toml", version_pattern='"MAJOR.MINOR.PATCH"')
+    _update_config_val("bumpver.toml", version_pattern='"MAJOR.MINOR.PATCH[PYTAGNUM]"')
 
-    _vcs_init("git", files=["bumpver.toml"])
+    if tag_scope is not None:
+        _update_config_val("bumpver.toml", tag_scope=f'"{tag_scope.value}"')
+
+    _vcs_init(vcs_name, files=["bumpver.toml"])
 
     result = runner.invoke(cli.cli, ['update', "--patch"])
     assert result.exit_code == 0
@@ -1253,9 +1469,158 @@ def test_get_latest_vcs_version_tag(runner):
     latest_version = cli.get_latest_vcs_version_tag(cfg, fetch=False)
     assert latest_version == "0.1.9"
 
+    if vcs_name == 'git':
+        shell("git", "branch", "dev")
+        shell("git", "checkout", "dev")
+    else:
+        shell("hg", "branch", "dev")
+
+    result = runner.invoke(cli.cli, ['update', "--minor", "--tag=beta"])
+    assert result.exit_code == 0
+
+    _, cfg = config.init()
+    latest_version = cli.get_latest_vcs_version_tag(cfg, fetch=False)
+    assert latest_version == "0.2.0b0"
+
+    if vcs_name == 'git':
+        shell("git", "checkout", "master")
+    else:
+        shell("hg", "update", "default")
+
+    result = runner.invoke(cli.cli, ['update', "--patch", "--tag=final"])
+    assert result.exit_code == 0
+
+    _, cfg = config.init()
+    latest_version = cli.get_latest_vcs_version_tag(cfg, fetch=False)
+    assert latest_version == expected_version
+
+
+@pytest.mark.parametrize("vcs_name", ['git', 'hg'])
+def test_ignore_vcs_tag(runner, monkeypatch, vcs_name):
+    result = runner.invoke(cli.cli, ['init', "-vv"])
+    assert result.exit_code == 0
+
+    _update_config_val("bumpver.toml", push="false")
+    _update_config_val("bumpver.toml", current_version='"0.1.8"')
+    _update_config_val("bumpver.toml", version_pattern='"MAJOR.MINOR.PATCH"')
+
+    _vcs_init(vcs_name, files=["bumpver.toml"])
+    _, cfg = config.init()
+
+    # mock latest vcs tag 0.2.0 but cfg.current_version is 0.1.8
+    monkeypatch.setattr(cli, "get_latest_vcs_version_tag", lambda cfg, fetch: "0.2.0")
+    assert cfg.current_version == "0.1.8"
+    assert cli.get_latest_vcs_version_tag(cfg, fetch=False) == "0.2.0"
+
+    result = runner.invoke(cli.cli, ['update', "--set-version", "0.1.9"])
+    assert result.exit_code == 1
+
+    result = runner.invoke(cli.cli, ['update', "-vv", "--ignore-vcs-tag", "--dry", "--set-version", "0.1.9"])
+    assert result.exit_code == 0
+
+    out_lines = set(result.output.splitlines())
+    assert '-current_version = "0.1.8"' in out_lines
+    assert '+current_version = "0.1.9"' in out_lines
+
+    latest_version = cli.get_latest_vcs_version_tag(cfg, fetch=False)
+    assert latest_version == "0.2.0"
+
+
+@pytest.mark.parametrize("vcs_name", ['git', 'hg'])
+def test_git_tag_scope_branch_version_conflict(runner, caplog, vcs_name):
+    result = runner.invoke(cli.cli, ['init', "-vv"])
+    assert result.exit_code == 0
+
+    _update_config_val("bumpver.toml", push="false")
+    _update_config_val("bumpver.toml", current_version='"0.1.8"')
+    _update_config_val("bumpver.toml", version_pattern='"MAJOR.MINOR.PATCH[PYTAGNUM]"')
+    _update_config_val("bumpver.toml", tag_scope=f'"{config.TagScope.BRANCH.value}"')
+
+    _vcs_init(vcs_name, files=["bumpver.toml"])
+
     result = runner.invoke(cli.cli, ['update', "--patch"])
     assert result.exit_code == 0
 
     _, cfg = config.init()
     latest_version = cli.get_latest_vcs_version_tag(cfg, fetch=False)
-    assert latest_version == "0.1.10"
+    assert latest_version == "0.1.9"
+
+    if vcs_name == 'git':
+        shell("git", "branch", "dev")
+        shell("git", "checkout", "dev")
+    else:
+        shell("hg", "branch", "dev")
+
+    result = runner.invoke(cli.cli, ['update', "--minor", "--tag=beta"])
+    assert result.exit_code == 0
+
+    _, cfg = config.init()
+    latest_version = cli.get_latest_vcs_version_tag(cfg, fetch=False)
+    assert latest_version == "0.2.0b0"
+
+    if vcs_name == 'git':
+        shell("git", "checkout", "master")
+    else:
+        shell("hg", "update", "default")
+
+    result = runner.invoke(cli.cli, ['update', "--minor", "--tag=beta"])
+    assert result.exit_code == 1
+
+    error_message = "Invariant violated: New version must be unique accross all branches"
+    assert any(error_message in r.message for r in caplog.records)
+
+
+def test_commit_hook_execution(runner, caplog):
+    result = runner.invoke(cli.cli, ['init'])
+    assert result.exit_code == 0
+
+    _update_config_val("bumpver.toml", push="false")
+    _update_config_val("bumpver.toml", current_version='"0.1.0"')
+    _update_config_val("bumpver.toml", version_pattern='"MAJOR.MINOR.PATCH"')
+
+    _vcs_init("git", files=["bumpver.toml"])
+
+    hooks_path = util.FIXTURES_DIR / "hooks"
+
+    cmd = [
+        'update',
+        '--minor',
+        '--pre-commit-hook',
+        f'{str(hooks_path / "pre_commit_hook.py")}',
+        '--post-commit-hook',
+        f'{str(hooks_path / "post_commit_hook.py")}',
+    ]
+
+    caplog.set_level(logging.INFO)
+    result = runner.invoke(cli.cli, cmd)
+    assert result.exit_code == 0
+
+    pre_commit_msg = "I'm a pre commit hook. The old version was: 0.1.0"
+    assert any(pre_commit_msg in r.message for r in caplog.records)
+
+    post_commit_msg = "I'm a post commit hook. The new version is: 0.2.0"
+    assert any(post_commit_msg in r.message for r in caplog.records)
+
+
+def test_commit_hook_execution_fail(runner, caplog):
+    result = runner.invoke(cli.cli, ['init'])
+    assert result.exit_code == 0
+
+    _update_config_val("bumpver.toml", push="false")
+
+    _vcs_init("git", files=["bumpver.toml"])
+
+    hooks_path = util.FIXTURES_DIR / "hooks"
+
+    cmd = [
+        'update',
+        '--pre-commit-hook',
+        f'{str(hooks_path / "pre_commit_hook_fail.py")}',
+    ]
+
+    result = runner.invoke(cli.cli, cmd)
+    assert result.exit_code == 1
+    assert len(caplog.records) > 0
+
+    log_msg = caplog.records[0].message
+    assert "Script exited with an error. Stopping" in log_msg
